@@ -3,6 +3,7 @@ from typing import NamedTuple, Any, Callable, Optional, List, Dict, Type, Tuple,
 
 from flask import request
 from pydantic import BaseModel, ValidationError, parse_obj_as, validate_arguments
+from pydantic.utils import deep_update
 
 from ul_api_utils.api_resource.api_request import ApiRequestQuery
 from ul_api_utils.api_resource.api_resource_type import ApiResourceType
@@ -116,7 +117,25 @@ class ApiResourceFnTyping(NamedTuple):
 
     def _get_body(self) -> Optional[Any]:
         if self.api_resource_type == ApiResourceType.WEB:
-            return request.form
+            res_dict: Dict[str, Any] = {}
+            for key, value in request.form.to_dict(flat=False).items():
+                if '[]' in key:
+                    key = key.replace('[]', '')
+                    res_dict[key] = value
+                elif '[' in key:
+                    key, *dict_keys = key.split('[')
+                    dict_keys = [dict_key[:-1] for dict_key in dict_keys]
+                    tree_dict: Dict[str, Any] = {}
+                    for iter, dict_key in enumerate(reversed(dict_keys)):
+                        if iter == 0:
+                            tree_dict = {dict_key: value[0]}
+                        else:
+                            tree_dict = {dict_key: tree_dict}
+                    res_dict.setdefault(key, dict())
+                    res_dict[key] = deep_update(res_dict[key], tree_dict)
+                else:
+                    res_dict[key] = value[0]
+            return res_dict
         if self.api_resource_type not in (ApiResourceType.API, ApiResourceType.FILE):
             return None
         if not request.is_json:
