@@ -4,6 +4,7 @@ from typing import List, Callable, Any, Optional, Dict, TYPE_CHECKING, Tuple, Na
 
 from pydantic import Field, BaseModel, parse_obj_as, PositiveInt, root_validator
 from sqlalchemy.sql import text
+from unipipeline.errors import UniError
 from unipipeline.modules.uni import Uni
 
 from ul_api_utils.api_resource.api_response import JsonApiResponsePayload
@@ -302,7 +303,6 @@ class HealthCheckContext:
         self,
         uni: Uni,
         override_queue_limits: Optional[Dict[str, 'HealthCheckMessageQueueRange']] = None,
-        exclude_queues: Optional[List[str]] = None,
     ) -> None:
         """
         Registers a wrapper for add_step but created with purpose
@@ -312,7 +312,6 @@ class HealthCheckContext:
             uni: Instance of Uni class with .dag config, usually can be found in lib.py in every service.
             override_queue_limits: Dictionary that contains queue name as a key, and HealthCheckMessageQueueRange
                                    with attributes **OK** and **WARN** set.
-            exclude_queues: List with queue names that you want to exclude from a health-check. F.E. output__old_lk
         """
         self.add_step(
             name="Message Queue Checks",
@@ -321,7 +320,6 @@ class HealthCheckContext:
             executable_kwargs={
                 "uni": uni,
                 "override_queue_limits": override_queue_limits,
-                "exclude_queues": exclude_queues,
             },
         )
 
@@ -347,7 +345,6 @@ class HealthCheckContext:
     def _message_queue_count_check(
         uni: Uni,
         override_queue_limits: Optional[Dict[str, 'HealthCheckMessageQueueRange']] = None,
-        exclude_queues: Optional[List[str]] = None,
     ) -> List['HealthCheckQueueStats']:
         """
         Retrieves all message broker queues and processing a status for each one of them.
@@ -357,8 +354,6 @@ class HealthCheckContext:
         """
         if override_queue_limits is None:
             override_queue_limits = {}
-        if exclude_queues is None:
-            exclude_queues = []
 
         queue_stats = []
         available_queues = [wd.topic for wd in uni.config.workers.values()]
@@ -367,10 +362,11 @@ class HealthCheckContext:
                 raise KeyError(f"Can't find queue with name {overriden_queue} in the list of available queues.")
 
         for wd in uni.config.workers.values():
-            if wd.topic in exclude_queues:
-                continue
             broker = uni._mediator.get_broker(wd.broker.name)
-            message_count = broker.get_topic_approximate_messages_count(wd.topic)
+            try:
+                message_count = broker.get_topic_approximate_messages_count(wd.topic)
+            except UniError:
+                continue
             if wd.topic in override_queue_limits:
                 overriden_queue_limit = override_queue_limits[wd.topic]
             else:
